@@ -64,12 +64,6 @@ class Users(_defaults_.Defaults):
 				"name":None,
 				"password":None,
 			},
-			"keys": {
-				"api_key":None,
-			},
-			# the requests.
-			"requests": {
-			},
 			# the permissions.
 			"permissions": {
 				"email":True,
@@ -78,6 +72,13 @@ class Users(_defaults_.Defaults):
 			"timestamps": {
 				"created":None,
 			},
+			# the keys.
+			"keys": {
+				"api_key":None,
+			},
+			# the requests.
+			"requests": {
+			},
 		}
 
 		#
@@ -127,15 +128,15 @@ class Users(_defaults_.Defaults):
 		user = response.user
 
 		# try load existing data.
-		response = self.db.load_data(email=email, username=username)
-		if response.success:
-			data = Dictionary(data).check(default=dict(self.default_user_data))
+		response = self.load_data(email=email, username=username, create=True)
+		if response.success and response.data != None:
+			data = Dictionary(response.data).check(default=dict(self.default_user_data))
 		else:
 			data = dict(self.default_user_data)
 
 		# save new user data.
 		data["timestamps"]["created"] = Date().date
-		data["keys"]["api_key"] = String("").generate(length=32, capitalize=True, digits=True)
+		data["keys"]["api_key"] = String().generate(length=48, capitalize=True, digits=True)
 		_response_ = self.aes.encrypt(password)
 		if not _response_.success: return _response_
 		try:data["account"]
@@ -146,6 +147,7 @@ class Users(_defaults_.Defaults):
 		data["account"]["password"] = _response_["encrypted"].decode()
 		response = self.save_data(email=email, username=username, data=data)
 		if not response.success: return response
+		print(response.message, data)
 
 		# insert api key cache.
 		try: self.__api_keys__
@@ -358,10 +360,12 @@ class Users(_defaults_.Defaults):
 		email=None,
 		# the user's username.
 		username=None,
+		# the create boolean (do not use).
+		create=False,
 	):	
 		if [username,email] == [None,None]:
 			return r3sponse.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
-		response = self.db.load(self.__get_path__(email=email, username=username), format="json")
+		response = self.db.load(path=self.__get_path__(email=email, username=username, create=create))
 		if response.error != None: return response
 		return r3sponse.success(f"Successfully loaded the data of user [{email}].", {
 			"data":response["data"],
@@ -373,10 +377,12 @@ class Users(_defaults_.Defaults):
 		username=None,
 		# the user's data.
 		data={},
+		# the overwrite boolean.
+		overwrite=False,
 	):
 		if [username,email] == [None,None]:
 			return r3sponse.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
-		response = self.db.save(self.__get_path__(email=email, username=username), data, format="json")
+		response = self.db.save(path=self.__get_path__(email=email, username=username, create=True), data=data, overwrite=overwrite)
 		if response.error != None: return response
 		return r3sponse.success(f"Successfully saved the data of user [{email}].")
 	def send_email(self, 
@@ -832,10 +838,10 @@ class Users(_defaults_.Defaults):
 				_emails_ = []
 				for path in Directory(Files.join(self.database, self.users_subpath)).paths(dirs_only=True):
 					id = gfp.name(path=path)
-					info = self.load_data(username=id, email=id).data
-					if info != None:
-						_users_.append(info["account"]["username"])
-						_emails_.append(info["account"]["email"])
+					response = self.load_data(username=id, email=id)
+					if response.success and response.data != None:
+						_users_.append(response.data["account"]["username"])
+						_emails_.append(response.data["account"]["email"])
 				if users:
 					return _users_
 				else:
@@ -900,7 +906,7 @@ class Users(_defaults_.Defaults):
 			try:
 				if data["keys"]["api_key"] in [None, ""]: raise KeyError("")
 			except KeyError: 
-				data["keys"]["api_key"] = String("").generate(length=32, capitalize=True, digits=True)
+				data["keys"]["api_key"] = String().generate(length=48, capitalize=True, digits=True)
 				edits += 1
 
 			# edits.
@@ -991,21 +997,26 @@ class Users(_defaults_.Defaults):
 		})
 
 		#
-	def __get_path__(self, email=None, username=None):
+	def __get_path__(self, email=None, username=None, create=False):
 		if self.id_by_username:
 			if username == None and email != None:
 				response = self.get(email=email)
 				if not response.success: response.crash()
 				username = response.user.username
 			id = username
+			if "@" in username:
+				raise ValueError(f"Forbidden @ character found in username: [{username}].")
 		else:
 			if email == None and username != None:
 				response = self.get(username=username)
 				if not response.success: response.crash()
 				email = response.user.email
 			id = email
+			if "@" not in email:
+				raise ValueError(f"Required @ character not found in email: [{email}].")
 		if self.db.mode == "cache":
 			path = f"{self.users_subpath}/{id}/settings"
+			if create and not Files.exists(gfp.base(path)): Files.create(gfp.base(path), directory=True)
 		else:
 			path = f"{self.users_subpath}/{id}"
 		return path
